# Table of Contents

- [meta-model-dora-extension](<./meta-model-dora-extension.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Digital Operational Resilience Act (DORA) Extension to the Meta Model](<./Digital-Operational-Resilience-Act-DORA-Extension-to-the-Meta-Model.md>)
  - [Overview](<./Digital-Operational-Resilience-Act-DORA-Extension-to-the-Meta-Model/Overview.md>)
  - [Activating the DORA Meta Model Extension](<./Digital-Operational-Resilience-Act-DORA-Extension-to-the-Meta-Model/Activating-the-DORA-Meta-Model-Extension.md>)
